@@ -1,7 +1,7 @@
 from datetime import date
 
 from cubicweb.entities import AnyEntity, fetch_config
-from cubicweb.entities.adapters import IMileStoneAdapter
+from cubicweb.entities.adapters import IMileStoneAdapter, IProgressAdapter
 from cubicweb.selectors import is_instance
 
 class Order(AnyEntity):
@@ -17,13 +17,6 @@ class Order(AnyEntity):
                 progress_done=sum(wod.progress_done or 0 for wod in workorders),
                 progress_todo=sum(wod.progress_todo or 0 for wod in workorders))
 
-    # XXX used somewhere? If so must be in an adapter
-    def progress_info(self):
-        return {'estimated': self.budget,
-                'estimatedcorrected': self.budget,
-                'done': self.progress_done,
-                'todo': self.progress_todo,
-                }
 
 class WorkOrder(AnyEntity):
     __regid__ = 'WorkOrder'
@@ -82,8 +75,55 @@ class WorkOrderIMileStoneAdapter(IMileStoneAdapter):
                 'done': self.entity.progress_done,
                 'todo': self.entity.progress_todo,}
 
+
 # XXX IMileStone / IProgress inheritance stink
 class WorkOrderProgressAdapter(WorkOrderIMileStoneAdapter):
     __regid__ = 'IProgress'
     __select__ = is_instance('WorkOrder')
 
+class OrderProgressAdapter(IProgressAdapter):
+    __select__ = is_instance('Order')
+
+    def progress_info(self):
+        return {'estimated': self.entity.budget,
+                'estimatedcorrected': self.entity.budget,
+                'done': self.entity.progress_done,
+                'todo': self.entity.progress_todo,
+                }
+
+    def in_progress(self):
+        return True # FIXME
+
+
+class OrderIMileStoneAdapter(IMileStoneAdapter):
+    __select__ = is_instance('Order')
+
+    def get_main_task(self):
+        return self.entity
+
+    def initial_prevision_date(self):
+        """returns the initial expected end of the milestone"""
+        return date.today()
+
+    def eta_date(self):
+        """returns expected date of completion based on what remains
+        to be done
+        """
+        return date.today()
+
+    def completion_date(self):
+        """returns date on which the subtask has been completed"""
+        return date.today()
+
+    def contractors(self):
+        """returns the list of persons supposed to work on this task"""
+        return []
+
+    def in_progress(self):
+        return self.entity.cw_adapt_to('IWorkflowable').state == u'in progress'
+
+    def progress_info(self):
+        return {'estimated': self.entity.budget,
+                'estimatedcorrected': self.entity.budget,
+                'done': self.entity.progress_done,
+                'todo': self.entity.progress_todo,}
